@@ -1,3 +1,5 @@
+import logging
+
 from facepy import GraphAPI, FacepyError
 
 from .base import BaseBackend
@@ -6,6 +8,8 @@ from ..exceptions import ImportFailed
 from ..utils import reraise_as
 from ..helpers import chunks
 
+logger = logging.getLogger('fairepart')
+
 
 class FacebookBackend(BaseBackend):
     name = 'facebook'
@@ -20,6 +24,8 @@ class FacebookBackend(BaseBackend):
         try:
             friends = self.get_friends(access_token)
         except FacepyError as e:
+            logger.exception(e)
+
             reraise_as(ImportFailed(self, access_token, e.message))
         else:
             uids = {}
